"""Helper methods for the :term:`API` module."""

from uuid import UUID

from fastapi import HTTPException
from orchestrator.services import processes
from pydantic import BaseModel
from starlette import status


def _start_process(process_name: str, data: dict) -> UUID:
    """Start a process and handle common exceptions."""
    pid: UUID = processes.start_process(process_name, [data])
    if pid is None:
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail="Failed to start the process.",
        )

    process = processes._get_process(pid)  # noqa: SLF001
    if process.last_status == "failed":
        raise HTTPException(
            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
            detail=f"Process {pid} failed because of an internal error. {process.failed_reason}",
        )

    return pid


class ImportResponseModel(BaseModel):
    """The model of a response given when services are imported using the :term:`API`."""

    pid: UUID
    detail: str
