""":term:`API` endpoints for importing office Routers."""

import ipaddress
from typing import Any

from fastapi import APIRouter, status
from pydantic import BaseModel

from gso.api.helpers import ImportResponseModel, _start_process
from gso.utils.shared_enums import PortNumber

router = APIRouter()


class OfficeRouterImportModel(BaseModel):
    """Required fields for importing an existing :class:`gso.product.product_types.office_router`."""

    partner: str
    office_router_site: str
    office_router_fqdn: str
    office_router_ts_port: PortNumber
    office_router_lo_ipv4_address: ipaddress.IPv4Address
    office_router_lo_ipv6_address: ipaddress.IPv6Address


@router.post("/office-routers", status_code=status.HTTP_201_CREATED, response_model=ImportResponseModel)
def create_imported_office_router(office_router_data: OfficeRouterImportModel) -> dict[str, Any]:
    """Import an office router by running the create_imported_office_router workflow.

    :param office_router_data: The office router information to be imported.
    :type office_router_data: OfficeRouterImportModel

    :return: A dictionary containing the process id of the started process and detail message.
    :rtype: dict[str, Any]

    :raises HTTPException: If there's an error in the process.
    """
    pid = _start_process("create_imported_office_router", office_router_data.dict())
    return {"detail": "Office router has been added successfully", "pid": pid}
