""":term:`API` endpoints for importing Routers."""

import ipaddress
from typing import Any

from fastapi import APIRouter, status
from pydantic import BaseModel

from gso.api.helpers import ImportResponseModel, _start_process
from gso.products.product_blocks.router import RouterRole
from gso.utils.shared_enums import Vendor

router = APIRouter()


class RouterImportModel(BaseModel):
    """Required fields for importing an existing :class:`gso.product.product_types.router`."""

    partner: str
    router_site: str
    hostname: str
    ts_port: int
    router_vendor: Vendor
    router_role: RouterRole
    router_lo_ipv4_address: ipaddress.IPv4Address
    router_lo_ipv6_address: ipaddress.IPv6Address
    router_lo_iso_address: str


@router.post("/routers", status_code=status.HTTP_201_CREATED, response_model=ImportResponseModel)
def create_imported_router(router_data: RouterImportModel) -> dict[str, Any]:
    """Import a router by running the create_imported_router workflow.

    :param router_data: The router information to be imported.
    :type router_data: RouterImportModel

    :return: A dictionary containing the process id of the started process and detail message.
    :rtype: dict[str, Any]

    :raises HTTPException: If there's an error in the process.
    """
    pid = _start_process("create_imported_router", router_data.dict())
    return {"detail": "Router has been added successfully", "pid": pid}
