""":term:`API` endpoints for importing Sites."""

from typing import Any

from fastapi import APIRouter, status

from gso.api.helpers import ImportResponseModel, _start_process
from gso.products.product_blocks.site import SiteTier
from gso.utils.helpers import BaseSiteValidatorModel

router = APIRouter()


class SiteImportModel(BaseSiteValidatorModel):
    """The required input for importing an existing :class:`gso.products.product_types.site`."""

    site_name: str
    site_city: str
    site_country: str
    site_country_code: str
    site_latitude: float
    site_longitude: float
    site_bgp_community_id: int
    site_internal_id: int
    site_tier: SiteTier
    site_ts_address: str
    partner: str


@router.post("/sites", status_code=status.HTTP_201_CREATED, response_model=ImportResponseModel)
def create_imported_site(site: SiteImportModel) -> dict[str, Any]:
    """Import a site by running the create_imported_site workflow.

    :param site: The site information to be imported.
    :type site: SiteImportModel

    :return: A dictionary containing the process id of the started process and detail message.
    :rtype: dict[str, Any]

    :raises HTTPException: If the site already exists or if there's an error in the process.
    """
    pid = _start_process("create_imported_site", site.dict())
    return {"detail": "Site added successfully.", "pid": pid}
