""":term:`API` endpoints for importing Super PoP switches."""

import ipaddress
from typing import Any

from fastapi import APIRouter, status
from pydantic import BaseModel

from gso.api.helpers import ImportResponseModel, _start_process
from gso.utils.shared_enums import PortNumber

router = APIRouter()


class SuperPopSwitchImportModel(BaseModel):
    """Required fields for importing an existing :class:`gso.product.product_types.super_pop_switch`."""

    partner: str
    super_pop_switch_site: str
    hostname: str
    super_pop_switch_ts_port: PortNumber
    super_pop_switch_mgmt_ipv4_address: ipaddress.IPv4Address


@router.post("/super-pop-switches", status_code=status.HTTP_201_CREATED, response_model=ImportResponseModel)
def create_imported_super_pop_switch(super_pop_switch_data: SuperPopSwitchImportModel) -> dict[str, Any]:
    """Import a Super PoP switch by running the create_imported_super_pop_switch workflow.

    :param super_pop_switch_data: The Super PoP switch information to be imported.
    :type super_pop_switch_data: SuperPopSwitchImportModel

    :return: A dictionary containing the process id of the started process and detail message.
    :rtype: dict[str, Any]

    :raises HTTPException: If there's an error in the process.
    """
    pid = _start_process("create_imported_super_pop_switch", super_pop_switch_data.dict())
    return {"detail": "Super PoP switch has been added successfully", "pid": pid}
